#!/usr/bin/env python
#
# Zenoss JSON API example to interact with Impact
#
# This will create a sample impact graph under organizer /api_test 
# then display a list of every service and service organizer.
#
# To run type:
#     python impact_api_example.py


from api_helper import ZenossAPIHelper, IMPACT_ROOT

api = ZenossAPIHelper()

def printTree():
    print "\nDisplaying tree of all services and organizers...\n"
    print "GUID                                 UID"
    print "---------------------------------    ---------------------"
    tree = api.get_services_tree()
    _printTreeRecursive(tree)

def _printTreeRecursive(tree):
    print tree['uuid'], tree['path']
    for child in tree['children']:
       _printTreeRecursive(child)


def createTree():
    print "\nCreating sample impact graph...\n"

    print "Deleting node if already exists: api_test"
    node = api.get_service_info(IMPACT_ROOT + '/api_test')
    if node['success']:
        print "Deleting node: api_test"
        result = api.delete_node(IMPACT_ROOT + '/api_test')

    print "Creating organizer: api_test"
    org = api.create_organizer(IMPACT_ROOT, 'api_test')
    if not org['success']:
        raise Exception("Unable to create organizer api_test")

    print "Creating services"
    orgUid = org['data']['uid']
    api.create_service(orgUid, 'Sample Service')
    api.create_service(orgUid, 'Server')
    api.create_service(orgUid, 'Database')
    api.create_service(orgUid, 'Network')

    print "Adding impacts"
    orgPath = orgUid + '/services/'
    api.add_impact(orgPath + 'Sample Service', orgPath + 'Server')
    api.add_impact(orgPath + 'Sample Service', orgPath + 'Database')
    api.add_impact(orgPath + 'Sample Service', orgPath + 'Network')

    print "Finished creating sample graph in organizer 'api_test'.\n"


if __name__ == '__main__':
    createTree()
    printTree()
